const path = require('path');
const HtmlWebpackPlugin = require('html-webpack-plugin')
const resolve = (src) => path.resolve(__dirname, src);


module.exports = {
    entry: resolve('src/main.tsx'),
    output: {
        filename: '[name].[contenthash].bundle.js',
        path: resolve('dist')
    },
    resolve: {
        extensions: [".ts", ".tsx", ".js"]
    },
    devtool: 'eval',
    module: {
        rules: [
            {
                test: /\.tsx?$/,
                exclude: /node_modules/,
                use: [
                    {
                        loader: 'babel-loader',
                        options: {
                            "presets": [
                                "@babel/preset-react",
                                [
                                    "@babel/preset-env",
                                    {
                                        "targets": "> 0.25%, not dead"
                                    }
                                ],

                            ]
                        }
                    },
                    {
                        loader: 'ts-loader',
                        options: {
                            // 指定特定的ts编译配置，为了区分脚本的ts配置
                            configFile: path.resolve(__dirname, './tsconfig.json'),
                        },
                    },
                ]
            },
            // {
            //     test: /\.jsx?$/,
            //     exclude: /node_modules/,
            //     use: [
            //         {
            //             loader: 'babel-loader',
            //             options: {
            //                 "presets": [
            //                     "@babel/preset-env"
            //                 ]
            //             }
            //         }
            //     ]
            // }
        ]
    },
    optimization: {
        splitChunks: {
            chunks: 'all',
        },
    },
    plugins: [
        new HtmlWebpackPlugin({
            filename: 'index.html',
            template: resolve('public/index.html'),
            inject: true
        })
    ],
    devServer: {
        contentBase: resolve('dist'),
        compress: true,
        port: 9000,
        open: true,

    },
}